@@ -31,6 +31,7 @@ Element::Element()
 {
   this->dataPtr->copyChildren = false;
   this->dataPtr->referenceSDF = "";
+  this->dataPtr->explicitlySetInFile = true;
 }
 
 /////////////////////////////////////////////////
@@ -93,6 +94,25 @@ void Element::SetCopyChildren(bool _value)
   this->dataPtr->copyChildren = _value;
 }
 
+/////////////////////////////////////////////////
+void Element::SetExplicitlySetInFile(const bool _value)
+{
+  this->dataPtr->explicitlySetInFile = _value;
+
+  ElementPtr_V::const_iterator eiter;
+  for (eiter = this->dataPtr->elements.begin();
+       eiter != this->dataPtr->elements.end(); ++eiter)
+  {
+    (*eiter)->SetExplicitlySetInFile(_value);
+  }
+}
+
+/////////////////////////////////////////////////
+bool Element::GetExplicitlySetInFile() const
+{
+  return this->dataPtr->explicitlySetInFile;
+}
+
 /////////////////////////////////////////////////
 bool Element::GetCopyChildren() const
 {
@@ -155,6 +175,7 @@ ElementPtr Element::Clone() const
   clone->dataPtr->referenceSDF = this->dataPtr->referenceSDF;
   clone->dataPtr->path = this->dataPtr->path;
   clone->dataPtr->originalVersion = this->dataPtr->originalVersion;
+  clone->dataPtr->explicitlySetInFile = this->dataPtr->explicitlySetInFile;
 
   Param_V::const_iterator aiter;
   for (aiter = this->dataPtr->attributes.begin();
@@ -196,6 +217,7 @@ void Element::Copy(const ElementPtr _elem)
   this->dataPtr->referenceSDF = _elem->ReferenceSDF();
   this->dataPtr->originalVersion = _elem->OriginalVersion();
   this->dataPtr->path = _elem->FilePath();
+  this->dataPtr->explicitlySetInFile = _elem->GetExplicitlySetInFile();
 
   for (Param_V::iterator iter = _elem->dataPtr->attributes.begin();
        iter != _elem->dataPtr->attributes.end(); ++iter)
@@ -255,8 +277,9 @@ void Element::PrintDescription(const std::string &_prefix) const
 
   std::cout << ">\n";
 
-  std::cout << _prefix << "  <description>" << this->dataPtr->description
-            << "</description>\n";
+  std::cout << _prefix << "  <description><![CDATA["
+            << this->dataPtr->description
+            << "]]></description>\n";
 
   Param_V::iterator aiter;
   for (aiter = this->dataPtr->attributes.begin();
@@ -266,8 +289,9 @@ void Element::PrintDescription(const std::string &_prefix) const
               << (*aiter)->GetKey() << "' type ='" << (*aiter)->GetTypeName()
               << "' default ='" << (*aiter)->GetDefaultAsString()
               << "' required ='" << (*aiter)->GetRequired() << "'>\n";
-    std::cout << _prefix << "    <description>" << (*aiter)->GetDescription()
-              << "</description>\n";
+    std::cout << _prefix << "    <description><![CDATA["
+              << (*aiter)->GetDescription()
+              << "]]></description>\n";
     std::cout << _prefix << "  </attribute>\n";
   }
 
@@ -418,47 +442,59 @@ void Element::PrintDocLeftPane(std::string &_html, int _spacing,
 }
 
 void Element::PrintValuesImpl(const std::string &_prefix,
+                              bool _includeDefaultElements,
+                              bool _includeDefaultAttributes,
                               std::ostringstream &_out) const
 {
-  _out << _prefix << "<" << this->dataPtr->name;
+  if (this->GetExplicitlySetInFile() || _includeDefaultElements)
+  {
+    _out << _prefix << "<" << this->dataPtr->name;
 
-  Param_V::const_iterator aiter;
-  for (aiter = this->dataPtr->attributes.begin();
-       aiter != this->dataPtr->attributes.end(); ++aiter)
-  {
-    // Only print attribute values if they were set
-    // TODO(anyone): GetRequired is added here to support up-conversions where a
-    // new required attribute with a default value is added. We would have
-    // better separation of concerns if the conversion process set the required
-    // attributes with their default values.
-    if ((*aiter)->GetSet() || (*aiter)->GetRequired())
+    Param_V::const_iterator aiter;
+    for (aiter = this->dataPtr->attributes.begin();
+         aiter != this->dataPtr->attributes.end(); ++aiter)
     {
-      _out << " " << (*aiter)->GetKey() << "='"
-           << (*aiter)->GetAsString() << "'";
+      // Only print attribute values if they were set
+      // TODO(anyone): GetRequired is added here to support up-conversions where
+      // a new required attribute with a default value is added. We would have
+      // better separation of concerns if the conversion process set the
+      // required attributes with their default values.
+      if ((*aiter)->GetSet() || (*aiter)->GetRequired() ||
+          _includeDefaultAttributes)
+      {
+        _out << " " << (*aiter)->GetKey() << "='"
+             << (*aiter)->GetAsString() << "'";
+      }
     }
-  }
 
-  if (this->dataPtr->elements.size() > 0)
-  {
-    _out << ">\n";
-    ElementPtr_V::const_iterator eiter;
-    for (eiter = this->dataPtr->elements.begin();
-         eiter != this->dataPtr->elements.end(); ++eiter)
+    if (this->dataPtr->elements.size() > 0)
     {
-      (*eiter)->ToString(_prefix + "  ", _out);
-    }
-    _out << _prefix << "</" << this->dataPtr->name << ">\n";
-  }
-  else
-  {
-    if (this->dataPtr->value)
-    {
-      _out << ">" << this->dataPtr->value->GetAsString()
-           << "</" << this->dataPtr->name << ">\n";
+      _out << ">\n";
+      ElementPtr_V::const_iterator eiter;
+      for (eiter = this->dataPtr->elements.begin();
+           eiter != this->dataPtr->elements.end(); ++eiter)
+      {
+        if ((*eiter)->GetExplicitlySetInFile() || _includeDefaultElements)
+        {
+          (*eiter)->ToString(_prefix + "  ",
+                             _includeDefaultElements,
+                             _includeDefaultAttributes,
+                             _out);
+        }
+      }
+      _out << _prefix << "</" << this->dataPtr->name << ">\n";
     }
     else
     {
-      _out << "/>\n";
+      if (this->dataPtr->value)
+      {
+        _out << ">" << this->dataPtr->value->GetAsString()
+             << "</" << this->dataPtr->name << ">\n";
+      }
+      else
+      {
+        _out << "/>\n";
+      }
     }
   }
 }
@@ -467,7 +503,20 @@ void Element::PrintValuesImpl(const std::string &_prefix,
 void Element::PrintValues(std::string _prefix) const
 {
   std::ostringstream ss;
-  PrintValuesImpl(_prefix, ss);
+  PrintValuesImpl(_prefix, true, false, ss);
+  std::cout << ss.str();
+}
+
+/////////////////////////////////////////////////
+void Element::PrintValues(const std::string &_prefix,
+                          bool _includeDefaultElements,
+                          bool _includeDefaultAttributes) const
+{
+  std::ostringstream ss;
+  PrintValuesImpl(_prefix,
+                  _includeDefaultElements,
+                  _includeDefaultAttributes,
+                  ss);
   std::cout << ss.str();
 }
 
@@ -475,17 +524,35 @@ void Element::PrintValues(std::string _prefix) const
 std::string Element::ToString(const std::string &_prefix) const
 {
   std::ostringstream out;
-  this->ToString(_prefix, out);
+  this->ToString(_prefix, true, false, out);
+  return out.str();
+}
+
+/////////////////////////////////////////////////
+std::string Element::ToString(const std::string &_prefix,
+                              bool _includeDefaultElements,
+                              bool _includeDefaultAttributes) const
+{
+  std::ostringstream out;
+  this->ToString(_prefix,
+                 _includeDefaultElements,
+                 _includeDefaultAttributes,
+                 out);
   return out.str();
 }
 
 /////////////////////////////////////////////////
 void Element::ToString(const std::string &_prefix,
+                       bool _includeDefaultElements,
+                       bool _includeDefaultAttributes,
                        std::ostringstream &_out) const
 {
   if (this->dataPtr->includeFilename.empty())
   {
-    PrintValuesImpl(_prefix, _out);
+    PrintValuesImpl(_prefix,
+                    _includeDefaultElements,
+                    _includeDefaultAttributes,
+                    _out);
   }
   else
   {
@@ -513,6 +580,27 @@ bool Element::GetAttributeSet(const std::string &_key) const
   return result;
 }
 
+/////////////////////////////////////////////////
+void Element::RemoveAttribute(const std::string &_key)
+{
+  Param_V::const_iterator iter;
+  for (iter = this->dataPtr->attributes.begin();
+      iter != this->dataPtr->attributes.end(); ++iter)
+  {
+    if ((*iter)->GetKey() == _key)
+    {
+      this->dataPtr->attributes.erase(iter);
+      break;
+    }
+  }
+}
+
+/////////////////////////////////////////////////
+void Element::RemoveAllAttributes()
+{
+  this->dataPtr->attributes.clear();
+}
+
 /////////////////////////////////////////////////
 ParamPtr Element::GetAttribute(const std::string &_key) const
 {
@@ -676,7 +764,15 @@ std::set<std::string> Element::GetElementTypeNames() const
 /////////////////////////////////////////////////
 bool Element::HasUniqueChildNames(const std::string &_type) const
 {
-  auto namedElementsCount = this->CountNamedElements(_type);
+  return this->HasUniqueChildNames(_type, {});
+}
+
+/////////////////////////////////////////////////
+bool Element::HasUniqueChildNames(
+    const std::string &_type,
+    const std::vector<std::string> &_ignoreElements) const
+{
+  auto namedElementsCount = this->CountNamedElements(_type, _ignoreElements);
   for (auto &iter : namedElementsCount)
   {
     if (iter.second > 1)
@@ -688,8 +784,16 @@ bool Element::HasUniqueChildNames(const std::string &_type) const
 }
 
 /////////////////////////////////////////////////
-std::map<std::string, std::size_t>
-Element::CountNamedElements(const std::string &_type) const
+std::map<std::string, std::size_t> Element::CountNamedElements(
+    const std::string &_type) const
+{
+  return this->CountNamedElements(_type, {});
+}
+
+/////////////////////////////////////////////////
+std::map<std::string, std::size_t> Element::CountNamedElements(
+    const std::string &_type,
+    const std::vector<std::string> &_ignoreElements) const
 {
   std::map<std::string, std::size_t> result;
 
@@ -705,7 +809,9 @@ Element::CountNamedElements(const std::string &_type) const
 
   while (elem)
   {
-    if (elem->HasAttribute("name"))
+    auto ignoreIt = std::find(_ignoreElements.begin(), _ignoreElements.end(),
+                              elem->GetName());
+    if (elem->HasAttribute("name") && ignoreIt == _ignoreElements.end())
     {
       // Get("name") returns attribute value if it exists before checking
       // for the value of a child element <name>, so it's safe to use
@@ -739,6 +845,18 @@ ElementPtr Element::GetElement(const std::string &_name)
   return result;
 }
 
+/////////////////////////////////////////////////
+ElementPtr Element::FindElement(const std::string &_name)
+{
+  return this->GetElementImpl(_name);
+}
+
+/////////////////////////////////////////////////
+ElementConstPtr Element::FindElement(const std::string &_name) const
+{
+  return this->GetElementImpl(_name);
+}
+
 /////////////////////////////////////////////////
 void Element::InsertElement(ElementPtr _elem)
 {
@@ -1001,3 +1119,10 @@ std::any Element::GetAny(const std::string &_key) const
   }
   return result;
 }
+
+//////////////////////////////////////////////////
+std::vector<std::string> Element::NameUniquenessExceptions()
+{
+  // We make exception for "plugin" when checking for name uniqueness.
+  return {"plugin"};
+}
