@@ -72,6 +72,98 @@ TEST(Element, Required)
   ASSERT_EQ(elem.GetRequired(), "1");
 }
 
+/////////////////////////////////////////////////
+TEST(Element, SetExplicitlySetInFile)
+{
+  // The heirarchy in xml:
+  // <parent>
+  //   <elem>
+  //     <child>
+  //       <child2>
+  //         <grandChild/>
+  //       <child2>
+  //     </child>
+  //     <sibling/>
+  //     <sibling2/>
+  //   </elem>
+  //   <elem2/>
+  // </parent>
+
+  sdf::ElementPtr parent = std::make_shared<sdf::Element>();
+  sdf::ElementPtr elem = std::make_shared<sdf::Element>();
+  elem->SetParent(parent);
+  parent->InsertElement(elem);
+  sdf::ElementPtr elem2 = std::make_shared<sdf::Element>();
+  elem2->SetParent(parent);
+  parent->InsertElement(elem2);
+
+  EXPECT_TRUE(elem->GetExplicitlySetInFile());
+
+  elem->SetExplicitlySetInFile(false);
+
+  EXPECT_FALSE(elem->GetExplicitlySetInFile());
+
+  elem->SetExplicitlySetInFile(true);
+
+  EXPECT_TRUE(elem->GetExplicitlySetInFile());
+
+  // the childs and siblings of the element should all be
+  // set to the same value when using this function
+  sdf::ElementPtr child = std::make_shared<sdf::Element>();
+  child->SetParent(elem);
+  elem->InsertElement(child);
+
+  sdf::ElementPtr sibling = std::make_shared<sdf::Element>();
+  sibling->SetParent(elem);
+  elem->InsertElement(sibling);
+
+  sdf::ElementPtr sibling2 = std::make_shared<sdf::Element>();
+  sibling2->SetParent(elem);
+  elem->InsertElement(sibling2);
+
+  sdf::ElementPtr child2 = std::make_shared<sdf::Element>();
+  child2->SetParent(child);
+  child->InsertElement(child2);
+
+  sdf::ElementPtr grandChild = std::make_shared<sdf::Element>();
+  grandChild->SetParent(child);
+  child->InsertElement(grandChild);
+
+  EXPECT_TRUE(elem->GetExplicitlySetInFile());
+  EXPECT_TRUE(child->GetExplicitlySetInFile());
+  EXPECT_TRUE(sibling->GetExplicitlySetInFile());
+  EXPECT_TRUE(sibling2->GetExplicitlySetInFile());
+  EXPECT_TRUE(child2->GetExplicitlySetInFile());
+  EXPECT_TRUE(grandChild->GetExplicitlySetInFile());
+  EXPECT_TRUE(elem2->GetExplicitlySetInFile());
+
+  elem->SetExplicitlySetInFile(false);
+  EXPECT_FALSE(elem->GetExplicitlySetInFile());
+  EXPECT_FALSE(child->GetExplicitlySetInFile());
+  EXPECT_FALSE(sibling->GetExplicitlySetInFile());
+  EXPECT_FALSE(sibling2->GetExplicitlySetInFile());
+  EXPECT_FALSE(child2->GetExplicitlySetInFile());
+  EXPECT_FALSE(grandChild->GetExplicitlySetInFile());
+
+  // SetExplicitlySetInFile(false) is be called only on `elem`. We expect
+  // GetExplicitlySetInFile() to be false for all children and grandchildren of
+  // `elem`, but true for `elem2`, which is a sibling of `elem`.
+  EXPECT_TRUE(elem2->GetExplicitlySetInFile());
+}
+
+/////////////////////////////////////////////////
+TEST(Element, SetExplicitlySetInFileWithInsert)
+{
+  sdf::ElementPtr parent = std::make_shared<sdf::Element>();
+  parent->SetExplicitlySetInFile(false);
+  sdf::ElementPtr child = std::make_shared<sdf::Element>();
+  child->SetParent(parent);
+  parent->InsertElement(child);
+
+  EXPECT_FALSE(parent->GetExplicitlySetInFile());
+  EXPECT_TRUE(child->GetExplicitlySetInFile());
+}
+
 /////////////////////////////////////////////////
 TEST(Element, CopyChildren)
 {
@@ -153,6 +245,40 @@ TEST(Element, GetAttributeSet)
   EXPECT_TRUE(elem.GetAttributeSet("test"));
 }
 
+/////////////////////////////////////////////////
+TEST(Element, RemoveAttribute)
+{
+  sdf::Element elem;
+  ASSERT_EQ(elem.GetAttributeCount(), 0UL);
+
+  elem.AddAttribute("test", "string", "foo", false, "foo description");
+  elem.AddAttribute("attr", "float", "0.0", false, "float description");
+  ASSERT_EQ(elem.GetAttributeCount(), 2UL);
+
+  elem.RemoveAttribute("test");
+  EXPECT_EQ(elem.GetAttributeCount(), 1UL);
+  EXPECT_EQ(elem.GetAttribute("test"), nullptr);
+  EXPECT_NE(elem.GetAttribute("attr"), nullptr);
+}
+
+/////////////////////////////////////////////////
+TEST(Element, RemoveAllAttributes)
+{
+  sdf::Element elem;
+  ASSERT_EQ(elem.GetAttributeCount(), 0UL);
+
+  elem.AddAttribute("test", "string", "foo", false, "foo description");
+  elem.AddAttribute("test2", "string", "foo", false, "foo description");
+  elem.AddAttribute("attr", "float", "0.0", false, "float description");
+  ASSERT_EQ(elem.GetAttributeCount(), 3UL);
+
+  elem.RemoveAllAttributes();
+  EXPECT_EQ(elem.GetAttributeCount(), 0UL);
+  EXPECT_EQ(elem.GetAttribute("test"), nullptr);
+  EXPECT_EQ(elem.GetAttribute("test2"), nullptr);
+  EXPECT_EQ(elem.GetAttribute("attr"), nullptr);
+}
+
 /////////////////////////////////////////////////
 TEST(Element, Include)
 {
@@ -283,6 +409,7 @@ TEST(Element, Clone)
   ASSERT_NE(newelem->GetFirstElement(), nullptr);
   ASSERT_EQ(newelem->GetElementDescriptionCount(), 1UL);
   ASSERT_EQ(newelem->GetAttributeCount(), 1UL);
+  ASSERT_TRUE(newelem->GetExplicitlySetInFile());
 }
 
 /////////////////////////////////////////////////
@@ -413,7 +540,6 @@ TEST(Element, ToStringValue)
             "myprefix< test='foo'>val</>\n");
 }
 
-
 /////////////////////////////////////////////////
 TEST(Element, ToStringClonedElement)
 {
@@ -448,6 +574,75 @@ TEST(Element, ToStringInclude)
   ASSERT_EQ(stringval, "myprefix<include filename='foo.txt'/>\n");
 }
 
+/////////////////////////////////////////////////
+TEST(Element, ToStringDefaultElements)
+{
+  sdf::ElementPtr parent = std::make_shared<sdf::Element>();
+  parent->SetName("parent");
+  sdf::ElementPtr elem = std::make_shared<sdf::Element>();
+  elem->SetName("elem");
+  elem->SetParent(parent);
+  parent->InsertElement(elem);
+  sdf::ElementPtr elem2 = std::make_shared<sdf::Element>();
+  elem2->SetName("elem2");
+  elem2->SetParent(parent);
+  parent->InsertElement(elem2);
+
+  std::ostringstream stream;
+  stream
+    << "<parent>\n"
+    << "  <elem/>\n"
+    << "  <elem2/>\n"
+    << "</parent>\n";
+
+  EXPECT_EQ(parent->ToString("", false, false), stream.str());
+  EXPECT_EQ(parent->ToString(""), stream.str());
+  EXPECT_EQ(parent->ToString("", true, false), stream.str());
+
+  elem->SetExplicitlySetInFile(false);
+
+  std::ostringstream stream2;
+  stream2
+    << "<parent>\n"
+    << "  <elem2/>\n"
+    << "</parent>\n";
+
+  EXPECT_EQ(parent->ToString("", false, false), stream2.str());
+  EXPECT_EQ(parent->ToString(""), stream.str());
+  EXPECT_EQ(parent->ToString("", true, false), stream.str());
+
+  parent->SetExplicitlySetInFile(false);
+
+  EXPECT_EQ(parent->ToString("", false, false), "");
+  EXPECT_EQ(parent->ToString(""), stream.str());
+  EXPECT_EQ(parent->ToString("", true, false), stream.str());
+}
+
+/////////////////////////////////////////////////
+TEST(Element, ToStringDefaultAttributes)
+{
+  sdf::ElementPtr element = std::make_shared<sdf::Element>();
+  element->SetName("foo");
+  element->AddAttribute("test", "string", "foo", false, "foo description");
+  element->AddAttribute("test2", "string", "bar", true, "bar description");
+
+  EXPECT_EQ(element->ToString(""), element->ToString("", true, false));
+  EXPECT_EQ(element->ToString(""), element->ToString("", false, false));
+
+  std::ostringstream stream;
+  stream << "<foo test2='bar'/>\n";
+
+  EXPECT_EQ(element->ToString(""), stream.str());
+  EXPECT_EQ(element->ToString("", true, false), stream.str());
+  EXPECT_EQ(element->ToString("", false, false), stream.str());
+
+  std::ostringstream stream2;
+  stream2 << "<foo test='foo' test2='bar'/>\n";
+
+  EXPECT_EQ(element->ToString("", true, true), stream2.str());
+  EXPECT_EQ(element->ToString("", false, true), stream2.str());
+}
+
 /////////////////////////////////////////////////
 TEST(Element, DocLeftPane)
 {
@@ -560,6 +755,7 @@ TEST(Element, Copy)
   ASSERT_EQ(param->GetDescription(), "val description");
 
   ASSERT_EQ(dest->GetAttributeCount(), 1UL);
+  ASSERT_TRUE(dest->GetExplicitlySetInFile());
   param = dest->GetAttribute("test");
   ASSERT_TRUE(param->IsType<std::string>());
   ASSERT_EQ(param->GetKey(), "test");
@@ -629,6 +825,25 @@ TEST(Element, GetNextElementMultiple)
   ASSERT_EQ(child2->GetNextElement(""), nullptr);
 }
 
+/////////////////////////////////////////////////
+/// Helper function to add child elements without having to create descriptions
+sdf::ElementPtr addChildElement(sdf::ElementPtr _parent,
+                                const std::string &_elementName,
+                                const bool _addNameAttribute,
+                                const std::string &_childName)
+{
+  sdf::ElementPtr child = std::make_shared<sdf::Element>();
+  child->SetParent(_parent);
+  child->SetName(_elementName);
+  _parent->InsertElement(child);
+
+  if (_addNameAttribute)
+  {
+    child->AddAttribute("name", "string", _childName, false, "description");
+  }
+  return child;
+}
+
 /////////////////////////////////////////////////
 TEST(Element, CountNamedElements)
 {
@@ -642,22 +857,6 @@ TEST(Element, CountNamedElements)
   EXPECT_TRUE(parent->HasUniqueChildNames());
   EXPECT_TRUE(parent->HasUniqueChildNames("child"));
 
-  auto addChildElement = [](
-      sdf::ElementPtr _parent,
-      const std::string &_elementName,
-      const bool _addNameAttribute,
-      const std::string &_childName)
-  {
-    sdf::ElementPtr child = std::make_shared<sdf::Element>();
-    child->SetParent(_parent);
-    child->SetName(_elementName);
-    _parent->InsertElement(child);
-
-    if (_addNameAttribute)
-    {
-      child->AddAttribute("name", "string", _childName, false, "description");
-    }
-  };
 
   // The following calls should make the following child elements:
   // <child name="child1"/>
@@ -718,6 +917,81 @@ TEST(Element, CountNamedElements)
   EXPECT_EQ(allMap.at("child3"), 1u);
 }
 
+TEST(Element, FindElement)
+{
+  // <root>
+  //   <elem_A>
+  //     <child_elem_A />
+  //   </elem_A>
+  //
+  //   <elem_B>
+  //     <child_elem_B name="first_child"/>
+  //     <child_elem_B/>
+  //   </elem_B>
+  // </root>
+  sdf::ElementPtr root = std::make_shared<sdf::Element>();
+  root->SetName("root");
+
+  // Create elements
+  {
+    auto elemA = addChildElement(root, "elem_A", false, "");
+    addChildElement(elemA, "child_elem_A", false, "");
+
+    auto elemB = addChildElement(root, "elem_B", false, "");
+    auto firstChildElemB =
+        addChildElement(elemB, "child_elem_B", true, "first_child");
+
+    addChildElement(elemB, "child_elem_B", false, "");
+  }
+
+  {
+    auto elemA = root->FindElement("elem_A");
+    ASSERT_NE(nullptr, elemA);
+    EXPECT_NE(nullptr, elemA->FindElement("child_elem_A"));
+    EXPECT_EQ(nullptr, elemA->FindElement("non_existent_elem"));
+
+    auto elemB = root->FindElement("elem_B");
+    ASSERT_NE(nullptr, elemB);
+    // This should find the first "child_elem_B" element, which has the name
+    // attribute
+    auto childElemB = elemB->FindElement("child_elem_B");
+    ASSERT_TRUE(childElemB->HasAttribute("name"));
+    EXPECT_EQ("first_child", childElemB->GetAttribute("name")->GetAsString());
+  }
+
+  // Check that it works with const pointers
+  {
+    sdf::ElementConstPtr rootConst = root;
+    sdf::ElementConstPtr elemA = rootConst->FindElement("elem_A");
+    ASSERT_NE(nullptr, elemA);
+    EXPECT_NE(nullptr, elemA->FindElement("child_elem_A"));
+    EXPECT_EQ(nullptr, elemA->FindElement("non_existent_elem"));
+
+    sdf::ElementConstPtr elemB = root->FindElement("elem_B");
+    ASSERT_NE(nullptr, elemB);
+    // This should find the first "child_elem_B" element, which has the name
+    // attribute
+    sdf::ElementConstPtr childElemB = elemB->FindElement("child_elem_B");
+    ASSERT_TRUE(childElemB->HasAttribute("name"));
+    EXPECT_EQ("first_child", childElemB->GetAttribute("name")->GetAsString());
+  }
+  {
+    sdf::ElementConstPtr rootConst = root;
+    sdf::ElementConstPtr elemA = rootConst->FindElement("elem_A");
+    ASSERT_NE(nullptr, elemA);
+    EXPECT_NE(nullptr, elemA->FindElement("child_elem_A"));
+    EXPECT_EQ(nullptr, elemA->FindElement("non_existent_elem"));
+
+    sdf::ElementConstPtr elemB = root->FindElement("elem_B");
+    ASSERT_NE(nullptr, elemB);
+    // This should find the first "child_elem_B" element, which has the name
+    // attribute
+    sdf::ElementConstPtr childElemB = elemB->FindElement("child_elem_B");
+    ASSERT_TRUE(childElemB->HasAttribute("name"));
+    EXPECT_EQ("first_child", childElemB->GetAttribute("name")->GetAsString());
+  }
+}
+
 /////////////////////////////////////////////////
 /// Main
 int main(int argc, char **argv)
