@@ -39,7 +39,6 @@ std::string Error::Message() const
 }
 
 /////////////////////////////////////////////////
-// cppcheck-suppress unusedFunction
 Error::operator bool() const
 {
   return this->code != ErrorCode::NONE;
@@ -51,3 +50,19 @@ bool Error::operator==(const bool _value) const
   return ((this->code != ErrorCode::NONE) && _value) ||
          ((this->code == ErrorCode::NONE) && !_value);
 }
+
+namespace sdf
+{
+// Inline bracket to help doxygen filtering.
+inline namespace SDF_VERSION_NAMESPACE {
+
+/////////////////////////////////////////////////
+std::ostream &operator<<(std::ostream &_out, const sdf::Error &_err)
+{
+  _out << "Error Code "
+    << static_cast<std::underlying_type<sdf::ErrorCode>::type>(_err.Code())
+    << " Msg: " << _err.Message();
+  return _out;
+}
+}
+}
