@@ -28,6 +28,7 @@
 #include "sdf/Types.hh"
 #include "FrameSemantics.hh"
 #include "Utils.hh"
+#include "sdf/parser.hh"
 
 using namespace sdf;
 
@@ -207,10 +208,15 @@ Errors Model::Load(ElementPtr _sdf)
   // Load the pose. Ignore the return value since the model pose is optional.
   loadPose(_sdf, this->dataPtr->pose, this->dataPtr->poseRelativeTo);
 
-  if (!_sdf->HasUniqueChildNames())
+  for (const auto &[name, size] :
+       _sdf->CountNamedElements("", Element::NameUniquenessExceptions()))
   {
-    sdfwarn << "Non-unique names detected in XML children of model with name["
-            << this->Name() << "].\n";
+    if (size > 1)
+    {
+      sdfwarn << "Non-unique name[" << name << "] detected " << size
+              << " times in XML children of model with name[" << this->Name()
+              << "].\n";
+    }
   }
 
   // Set of implicit and explicit frame names in this model for tracking
@@ -409,6 +415,35 @@ Errors Model::Load(ElementPtr _sdf)
   return errors;
 }
 
+/////////////////////////////////////////////////
+Errors Model::ValidateGraphs() const
+{
+  Errors errors;
+  if (!this->dataPtr->frameAttachedToGraph)
+  {
+    errors.push_back({ErrorCode::FRAME_ATTACHED_TO_GRAPH_ERROR,
+        "FrameAttachedToGraph pointer is null."});
+  }
+  else
+  {
+    errors = validateFrameAttachedToGraph(*this->dataPtr->frameAttachedToGraph);
+  }
+
+  if (!this->dataPtr->poseGraph)
+  {
+    errors.push_back({ErrorCode::POSE_RELATIVE_TO_GRAPH_ERROR,
+        "PoseRelativeToGraph pointer is null."});
+  }
+  else
+  {
+    Errors poseErrors =
+        validatePoseRelativeToGraph(*this->dataPtr->poseGraph);
+    errors.insert(errors.end(), poseErrors.begin(), poseErrors.end());
+  }
+
+  return errors;
+}
+
 /////////////////////////////////////////////////
 std::string Model::Name() const
 {
@@ -466,7 +501,7 @@ bool Model::EnableWind() const
 /////////////////////////////////////////////////
 void Model::SetEnableWind(const bool _enableWind)
 {
-  this->dataPtr->enableWind =_enableWind;
+  this->dataPtr->enableWind = _enableWind;
 }
 
 /////////////////////////////////////////////////
