@@ -22,6 +22,8 @@
 #include "sdf/Altimeter.hh"
 #include "sdf/Camera.hh"
 #include "sdf/Error.hh"
+#include "sdf/ForceTorque.hh"
+#include "sdf/NavSat.hh"
 #include "sdf/Imu.hh"
 #include "sdf/Magnetometer.hh"
 #include "sdf/Lidar.hh"
@@ -55,7 +57,8 @@ const std::vector<std::string> sensorTypeStrs =
   "wireless_transmitter",
   "air_pressure",
   "rgbd_camera",
-  "thermal_camera"
+  "thermal_camera",
+  "navsat"
 };
 
 class sdf::SensorPrivate
@@ -71,6 +74,7 @@ class sdf::SensorPrivate
             pose(_sensor.pose),
             poseRelativeTo(_sensor.poseRelativeTo),
             sdf(_sensor.sdf),
+            enableMetrics(_sensor.enableMetrics),
             updateRate(_sensor.updateRate)
 
   {
@@ -79,6 +83,10 @@ class sdf::SensorPrivate
       this->magnetometer = std::make_unique<sdf::Magnetometer>(
           *_sensor.magnetometer);
     }
+    if (_sensor.navSat)
+    {
+      this->navSat = std::make_unique<sdf::NavSat>(*_sensor.navSat);
+    }
     if (_sensor.altimeter)
     {
       this->altimeter = std::make_unique<sdf::Altimeter>(*_sensor.altimeter);
@@ -92,6 +100,11 @@ class sdf::SensorPrivate
     {
       this->camera = std::make_unique<sdf::Camera>(*_sensor.camera);
     }
+    if (_sensor.forceTorque)
+    {
+      this->forceTorque = std::make_unique<sdf::ForceTorque>(
+          *_sensor.forceTorque);
+    }
     if (_sensor.imu)
     {
       this->imu = std::make_unique<sdf::Imu>(*_sensor.imu);
@@ -125,6 +138,9 @@ class sdf::SensorPrivate
   /// \brief The SDF element pointer used during load.
   public: sdf::ElementPtr sdf;
 
+  /// \brief Performance metrics flag.
+  public: bool enableMetrics{false};
+
   /// \brief Name of xml parent object.
   public: std::string xmlParentName;
 
@@ -137,12 +153,18 @@ class sdf::SensorPrivate
   /// \brief Pointer to an altimeter.
   public: std::unique_ptr<Altimeter> altimeter;
 
+  /// \brief Pointer to NAVSAT sensor.
+  public: std::unique_ptr<NavSat> navSat;
+
   /// \brief Pointer to an air pressure sensor.
   public: std::unique_ptr<AirPressure> airPressure;
 
   /// \brief Pointer to a camera.
   public: std::unique_ptr<Camera> camera;
 
+  /// \brief Pointer to a force torque sensor.
+  public: std::unique_ptr<ForceTorque> forceTorque;
+
   /// \brief Pointer to an IMU.
   public: std::unique_ptr<Imu> imu;
 
@@ -205,6 +227,7 @@ bool Sensor::operator==(const Sensor &_sensor) const
       this->Topic() != _sensor.Topic() ||
       this->RawPose() != _sensor.RawPose() ||
       this->PoseRelativeTo() != _sensor.PoseRelativeTo() ||
+      this->EnableMetrics() != _sensor.EnableMetrics() ||
       !ignition::math::equal(this->UpdateRate(), _sensor.UpdateRate()))
   {
     return false;
@@ -219,8 +242,12 @@ bool Sensor::operator==(const Sensor &_sensor) const
       return *(this->dataPtr->magnetometer) == *(_sensor.dataPtr->magnetometer);
     case SensorType::AIR_PRESSURE:
       return *(this->dataPtr->airPressure) == *(_sensor.dataPtr->airPressure);
+    case SensorType::FORCE_TORQUE:
+      return *(this->dataPtr->forceTorque) == *(_sensor.dataPtr->forceTorque);
     case SensorType::IMU:
       return *(this->dataPtr->imu) == *(_sensor.dataPtr->imu);
+    case SensorType::NAVSAT:
+      return *(this->dataPtr->navSat) == *(_sensor.dataPtr->navSat);
     case SensorType::CAMERA:
     case SensorType::DEPTH_CAMERA:
     case SensorType::RGBD_CAMERA:
@@ -288,6 +315,8 @@ Errors Sensor::Load(ElementPtr _sdf)
   if (this->dataPtr->topic == "__default__")
     this->dataPtr->topic = "";
 
+  this->dataPtr->enableMetrics = _sdf->Get<bool>("enable_metrics",
+      this->dataPtr->enableMetrics).first;
   std::string type = _sdf->Get<std::string>("type");
   if (type == "air_pressure")
   {
@@ -339,10 +368,18 @@ Errors Sensor::Load(ElementPtr _sdf)
   else if (type == "force_torque")
   {
     this->dataPtr->type = SensorType::FORCE_TORQUE;
+    this->dataPtr->forceTorque.reset(new ForceTorque());
+    Errors err = this->dataPtr->forceTorque->Load(
+        _sdf->GetElement("force_torque"));
+    errors.insert(errors.end(), err.begin(), err.end());
   }
-  else if (type == "gps")
+  else if (type == "navsat" || type == "gps")
   {
-    this->dataPtr->type = SensorType::GPS;
+    this->dataPtr->type = SensorType::NAVSAT;
+    this->dataPtr->navSat.reset(new NavSat());
+    Errors err = this->dataPtr->navSat->Load(
+      _sdf->GetElement(_sdf->HasElement("navsat") ? "navsat" : "gps"));
+    errors.insert(errors.end(), err.begin(), err.end());
   }
   else if (type == "gpu_ray" || type == "gpu_lidar")
   {
@@ -354,7 +391,6 @@ Errors Sensor::Load(ElementPtr _sdf)
   }
   else if (type == "imu")
   {
-    this->dataPtr->type = SensorType::IMU;
     this->dataPtr->type = SensorType::IMU;
     this->dataPtr->imu.reset(new Imu());
     Errors err = this->dataPtr->imu->Load(_sdf->GetElement("imu"));
@@ -503,6 +539,18 @@ void Sensor::SetPoseRelativeToGraph(
   this->dataPtr->poseRelativeToGraph = _graph;
 }
 
+/////////////////////////////////////////////////
+bool Sensor::EnableMetrics() const
+{
+  return this->dataPtr->enableMetrics;
+}
+
+/////////////////////////////////////////////////
+void Sensor::SetEnableMetrics(bool _enableMetrics)
+{
+  this->dataPtr->enableMetrics = _enableMetrics;
+}
+
 /////////////////////////////////////////////////
 sdf::SemanticPose Sensor::SemanticPose() const
 {
@@ -626,6 +674,30 @@ const Camera *Sensor::CameraSensor() const
   return this->dataPtr->camera.get();
 }
 
+/////////////////////////////////////////////////
+void Sensor::SetForceTorqueSensor(const ForceTorque &_ft)
+{
+  this->dataPtr->forceTorque = std::make_unique<ForceTorque>(_ft);
+}
+
+/////////////////////////////////////////////////
+const ForceTorque *Sensor::ForceTorqueSensor() const
+{
+  return this->dataPtr->forceTorque.get();
+}
+
+/////////////////////////////////////////////////
+void Sensor::SetNavSatSensor(const NavSat &_gps)
+{
+  this->dataPtr->navSat = std::make_unique<NavSat>(_gps);
+}
+
+/////////////////////////////////////////////////
+const NavSat *Sensor::NavSatSensor() const
+{
+  return this->dataPtr->navSat.get();
+}
+
 /////////////////////////////////////////////////
 void Sensor::SetImuSensor(const Imu &_imu)
 {
