@@ -28,6 +28,7 @@
 #include "sdf/World.hh"
 #include "FrameSemantics.hh"
 #include "Utils.hh"
+#include "sdf/parser.hh"
 
 using namespace sdf;
 
@@ -255,10 +256,15 @@ Errors World::Load(sdf::ElementPtr _sdf)
     _sdf->Get<ignition::math::Vector3d>("magnetic_field",
         this->dataPtr->magneticField).first;
 
-  if (!_sdf->HasUniqueChildNames())
+  for (const auto &[name, size] :
+       _sdf->CountNamedElements("", Element::NameUniquenessExceptions()))
   {
-    sdfwarn << "Non-unique names detected in XML children of world with name["
-            << this->Name() << "].\n";
+    if (size > 1)
+    {
+      sdfwarn << "Non-unique name[" << name << "] detected " << size
+              << " times in XML children of world with name[" << this->Name()
+              << "].\n";
+    }
   }
 
   // Set of implicit and explicit frame names in this model for tracking
@@ -386,6 +392,35 @@ Errors World::Load(sdf::ElementPtr _sdf)
   return errors;
 }
 
+/////////////////////////////////////////////////
+Errors World::ValidateGraphs() const
+{
+  Errors errors;
+  if (!this->dataPtr->frameAttachedToGraph)
+  {
+    errors.push_back({ErrorCode::FRAME_ATTACHED_TO_GRAPH_ERROR,
+        "FrameAttachedToGraph pointer is null."});
+  }
+  else
+  {
+    errors = validateFrameAttachedToGraph(*this->dataPtr->frameAttachedToGraph);
+  }
+
+  if (!this->dataPtr->poseRelativeToGraph)
+  {
+    errors.push_back({ErrorCode::POSE_RELATIVE_TO_GRAPH_ERROR,
+        "PoseRelativeToGraph pointer is null."});
+  }
+  else
+  {
+    Errors poseErrors =
+        validatePoseRelativeToGraph(*this->dataPtr->poseRelativeToGraph);
+    errors.insert(errors.end(), poseErrors.begin(), poseErrors.end());
+  }
+
+  return errors;
+}
+
 /////////////////////////////////////////////////
 std::string World::Name() const
 {
