@@ -301,8 +301,7 @@ TEST(Frame, StateFrame)
 TEST(Frame, IncludeRelativeTo)
 {
   const std::string MODEL_PATH =
-    sdf::filesystem::append(PROJECT_SOURCE_PATH, "test", "integration",
-                            "model", "box");
+    sdf::testing::TestFile("integration", "model", "box");
 
   std::ostringstream stream;
   std::string version = SDF_VERSION;
@@ -348,8 +347,7 @@ TEST(Frame, IncludeRelativeTo)
 TEST(Frame, IncludeRelativeToEmptyPose)
 {
   const std::string MODEL_PATH =
-    sdf::filesystem::append(PROJECT_SOURCE_PATH, "test", "integration",
-                            "model", "box");
+    sdf::testing::TestFile("integration", "model", "box");
 
   std::ostringstream stream;
   std::string version = SDF_VERSION;
@@ -415,8 +413,7 @@ TEST(Frame, IncludeRelativeToEmptyPose)
 TEST(DOMFrame, LoadModelFramesAttachedTo)
 {
   const std::string testFile =
-    sdf::filesystem::append(PROJECT_SOURCE_PATH, "test", "sdf",
-        "model_frame_attached_to.sdf");
+    sdf::testing::TestFile("sdf", "model_frame_attached_to.sdf");
 
   // Load the SDF file
   sdf::Root root;
@@ -475,7 +472,7 @@ TEST(DOMFrame, LoadModelFramesAttachedTo)
 TEST(DOMFrame, LoadModelFramesInvalidAttachedTo)
 {
   const std::string testFile =
-    sdf::filesystem::append(PROJECT_SOURCE_PATH, "test", "sdf",
+    sdf::testing::TestFile("sdf",
         "model_frame_invalid_attached_to.sdf");
 
   // Load the SDF file
@@ -510,14 +507,74 @@ TEST(DOMFrame, LoadModelFramesInvalidAttachedTo)
       "causing a graph cycle"));
   // errors[7]
   // errors[8]
-  // errors[9]
+  EXPECT_EQ(errors[9].Code(), sdf::ErrorCode::POSE_RELATIVE_TO_CYCLE);
+  EXPECT_NE(std::string::npos,
+    errors[9].Message().find(
+      "PoseRelativeToGraph cycle detected, "
+      "already visited vertex [F4]"));
+
+  // Try loading sdf::Model object
+  sdf::SDFPtr sdfParsed(new sdf::SDF());
+  sdf::init(sdfParsed);
+  ASSERT_TRUE(sdf::readFile(testFile, sdfParsed));
+
+  auto rootElem = sdfParsed->Root();
+  ASSERT_NE(nullptr, rootElem);
+  ASSERT_TRUE(rootElem->HasElement("model"));
+  auto modelElem = rootElem->GetElement("model");
+  ASSERT_NE(nullptr, modelElem);
+
+  // the first 10 errors from loading an sdf::Model match the first 10 errors
+  // from loading an sdf::Root
+  sdf::Model model;
+  auto modelLoadErrors = model.Load(modelElem);
+  ASSERT_EQ(10u, modelLoadErrors.size());
+  for (int i = 0; i < 10; ++i)
+  {
+    EXPECT_EQ(errors[i].Code(), modelLoadErrors[i].Code());
+    EXPECT_EQ(errors[i].Message(), modelLoadErrors[i].Message());
+  }
+
+  errors = model.ValidateGraphs();
+  EXPECT_EQ(6u, errors.size());
+  EXPECT_EQ(errors[0].Code(), sdf::ErrorCode::FRAME_ATTACHED_TO_GRAPH_ERROR);
+  EXPECT_NE(std::string::npos,
+    errors[0].Message().find(
+      "FrameAttachedToGraph error, Non-LINK vertex with name [F3] is "
+      "disconnected; it should have 1 outgoing edge in MODEL attached_to "
+      "graph.")) << errors[0];
+  EXPECT_EQ(errors[1].Code(), sdf::ErrorCode::FRAME_ATTACHED_TO_GRAPH_ERROR);
+  EXPECT_NE(std::string::npos,
+    errors[1].Message().find(
+      "Graph has __model__ scope but sink vertex named [F3] does not have "
+      "FrameType LINK or MODEL when starting from vertex with name [F3]"))
+      << errors[1];
+  EXPECT_EQ(errors[2].Code(), sdf::ErrorCode::FRAME_ATTACHED_TO_CYCLE);
+  EXPECT_NE(std::string::npos,
+    errors[2].Message().find(
+      "cycle detected, already visited vertex [F4]")) << errors[2];
+  EXPECT_EQ(errors[3].Code(), sdf::ErrorCode::POSE_RELATIVE_TO_GRAPH_ERROR);
+  EXPECT_NE(std::string::npos,
+    errors[3].Message().find(
+      "Vertex with name [F3] is disconnected; it should have "
+      "1 incoming edge in MODEL relative_to graph")) << errors[3];
+  EXPECT_EQ(errors[4].Code(), sdf::ErrorCode::POSE_RELATIVE_TO_GRAPH_ERROR);
+  EXPECT_NE(std::string::npos,
+    errors[4].Message().find(
+      "frame with name [F3] is disconnected; its source vertex has name [F3], "
+      "but its source name should be __model__")) << errors[4];
+  EXPECT_EQ(errors[5].Code(), sdf::ErrorCode::POSE_RELATIVE_TO_CYCLE);
+  EXPECT_NE(std::string::npos,
+    errors[5].Message().find(
+      "PoseRelativeToGraph cycle detected, "
+      "already visited vertex [F4]")) << errors[5];
 }
 
 /////////////////////////////////////////////////
 TEST(DOMFrame, LoadModelFramesAttachedToJoint)
 {
   const std::string testFile =
-    sdf::filesystem::append(PROJECT_SOURCE_PATH, "test", "sdf",
+    sdf::testing::TestFile("sdf",
         "model_frame_attached_to_joint.sdf");
 
   // Load the SDF file
@@ -582,7 +639,7 @@ TEST(DOMFrame, LoadModelFramesAttachedToJoint)
 TEST(DOMFrame, LoadModelFramesAttachedToNestedModel)
 {
   const std::string testFile =
-    sdf::filesystem::append(PROJECT_SOURCE_PATH, "test", "sdf",
+    sdf::testing::TestFile("sdf",
         "model_frame_attached_to_nested_model.sdf");
 
   // Load the SDF file
@@ -631,7 +688,7 @@ TEST(DOMFrame, LoadModelFramesAttachedToNestedModel)
 TEST(DOMFrame, LoadWorldFramesAttachedTo)
 {
   const std::string testFile =
-    sdf::filesystem::append(PROJECT_SOURCE_PATH, "test", "sdf",
+    sdf::testing::TestFile("sdf",
         "world_frame_attached_to.sdf");
 
   // Load the SDF file
@@ -698,7 +755,7 @@ TEST(DOMFrame, LoadWorldFramesAttachedTo)
 TEST(DOMFrame, LoadWorldFramesInvalidAttachedTo)
 {
   const std::string testFile =
-    sdf::filesystem::append(PROJECT_SOURCE_PATH, "test", "sdf",
+    sdf::testing::TestFile("sdf",
         "world_frame_invalid_attached_to.sdf");
 
   // Load the SDF file
@@ -720,6 +777,7 @@ TEST(DOMFrame, LoadWorldFramesInvalidAttachedTo)
       "causing a graph cycle"));
   // errors[2]
   // errors[3]
+  // errors[4]
   EXPECT_EQ(errors[5].Code(), sdf::ErrorCode::FRAME_ATTACHED_TO_INVALID);
   EXPECT_NE(std::string::npos,
     errors[5].Message().find(
@@ -730,16 +788,78 @@ TEST(DOMFrame, LoadWorldFramesInvalidAttachedTo)
     errors[6].Message().find(
       "relative_to name[self_cycle] is identical to frame name[self_cycle], "
       "causing a graph cycle"));
-  // errors[6]
   // errors[7]
   // errors[8]
+  EXPECT_EQ(errors[9].Code(), sdf::ErrorCode::POSE_RELATIVE_TO_CYCLE);
+  EXPECT_NE(std::string::npos,
+    errors[9].Message().find(
+      "PoseRelativeToGraph cycle detected, "
+      "already visited vertex [self_cycle]"));
+  EXPECT_EQ(errors[10].Code(), sdf::ErrorCode::ELEMENT_INVALID);
+  EXPECT_NE(std::string::npos,
+    errors[10].Message().find(
+      "Failed to load a world"));
+
+  // Try loading sdf::World object
+  sdf::SDFPtr sdfParsed(new sdf::SDF());
+  sdf::init(sdfParsed);
+  ASSERT_TRUE(sdf::readFile(testFile, sdfParsed));
+
+  auto rootElem = sdfParsed->Root();
+  ASSERT_NE(nullptr, rootElem);
+  ASSERT_TRUE(rootElem->HasElement("world"));
+  auto worldElem = rootElem->GetElement("world");
+  ASSERT_NE(nullptr, worldElem);
+
+  // the first 10 errors from loading an sdf::World match the first 10 errors
+  // from loading an sdf::Root
+  sdf::World world;
+  auto worldLoadErrors = world.Load(worldElem);
+  ASSERT_EQ(10u, worldLoadErrors.size());
+  for (int i = 0; i < 10; ++i)
+  {
+    EXPECT_EQ(errors[i].Code(), worldLoadErrors[i].Code());
+    EXPECT_EQ(errors[i].Message(), worldLoadErrors[i].Message());
+  }
+
+  errors = world.ValidateGraphs();
+  EXPECT_EQ(6u, errors.size());
+  EXPECT_EQ(errors[0].Code(), sdf::ErrorCode::FRAME_ATTACHED_TO_GRAPH_ERROR);
+  EXPECT_NE(std::string::npos,
+    errors[0].Message().find(
+      "FrameAttachedToGraph error, FRAME vertices in WORLD attached_to graph "
+      "should have 1 outgoing edge"));
+  EXPECT_EQ(errors[1].Code(), sdf::ErrorCode::FRAME_ATTACHED_TO_GRAPH_ERROR);
+  EXPECT_NE(std::string::npos,
+    errors[1].Message().find(
+      "Graph has world scope but sink vertex named [F] does not have "
+      "FrameType WORLD or MODEL when starting from vertex with name [F]"));
+  EXPECT_EQ(errors[2].Code(), sdf::ErrorCode::FRAME_ATTACHED_TO_CYCLE);
+  EXPECT_NE(std::string::npos,
+    errors[2].Message().find(
+      "cycle detected, already visited vertex [self_cycle]"));
+  EXPECT_EQ(errors[3].Code(), sdf::ErrorCode::POSE_RELATIVE_TO_GRAPH_ERROR);
+  EXPECT_NE(std::string::npos,
+    errors[3].Message().find(
+      "MODEL / FRAME vertex with name [F] is disconnected; it should have "
+      "1 incoming edge in WORLD relative_to graph"));
+  EXPECT_EQ(errors[4].Code(), sdf::ErrorCode::POSE_RELATIVE_TO_GRAPH_ERROR);
+  EXPECT_NE(std::string::npos,
+    errors[4].Message().find(
+      "frame with name [F] is disconnected; its source vertex has name [F], "
+      "but its source name should be world"));
+  EXPECT_EQ(errors[5].Code(), sdf::ErrorCode::POSE_RELATIVE_TO_CYCLE);
+  EXPECT_NE(std::string::npos,
+    errors[5].Message().find(
+      "PoseRelativeToGraph cycle detected, "
+      "already visited vertex [self_cycle]"));
 }
 
 /////////////////////////////////////////////////
 TEST(DOMFrame, LoadModelFramesRelativeTo)
 {
   const std::string testFile =
-    sdf::filesystem::append(PROJECT_SOURCE_PATH, "test", "sdf",
+    sdf::testing::TestFile("sdf",
         "model_frame_relative_to.sdf");
 
   // Load the SDF file
@@ -872,7 +992,7 @@ TEST(DOMFrame, LoadModelFramesRelativeTo)
 TEST(DOMFrame, LoadModelFramesInvalidRelativeTo)
 {
   const std::string testFile =
-    sdf::filesystem::append(PROJECT_SOURCE_PATH, "test", "sdf",
+    sdf::testing::TestFile("sdf",
         "model_invalid_frame_relative_to.sdf");
 
   // Load the SDF file
@@ -900,7 +1020,7 @@ TEST(DOMFrame, LoadModelFramesInvalidRelativeTo)
 TEST(DOMFrame, LoadModelFramesRelativeToJoint)
 {
   const std::string testFile =
-    sdf::filesystem::append(PROJECT_SOURCE_PATH, "test", "sdf",
+    sdf::testing::TestFile("sdf",
         "model_frame_relative_to_joint.sdf");
 
   // Load the SDF file
@@ -1034,7 +1154,7 @@ TEST(DOMFrame, LoadModelFramesRelativeToJoint)
 TEST(DOMFrame, LoadWorldFramesRelativeTo)
 {
   const std::string testFile =
-    sdf::filesystem::append(PROJECT_SOURCE_PATH, "test", "sdf",
+    sdf::testing::TestFile("sdf",
         "world_frame_relative_to.sdf");
 
   // Load the SDF file
@@ -1100,7 +1220,7 @@ TEST(DOMFrame, LoadWorldFramesRelativeTo)
 TEST(DOMFrame, LoadWorldFramesInvalidRelativeTo)
 {
   const std::string testFile =
-    sdf::filesystem::append(PROJECT_SOURCE_PATH, "test", "sdf",
+    sdf::testing::TestFile("sdf",
         "world_frame_invalid_relative_to.sdf");
 
   // Load the SDF file
@@ -1126,8 +1246,7 @@ TEST(DOMFrame, LoadWorldFramesInvalidRelativeTo)
 TEST(DOMFrame, WorldIncludeModel)
 {
   const std::string MODEL_PATH =
-    sdf::filesystem::append(PROJECT_SOURCE_PATH, "test", "integration",
-                            "model", "box");
+    sdf::testing::TestFile("integration", "model", "box");
 
   std::ostringstream stream;
   std::string version = SDF_VERSION;
