@@ -20,12 +20,14 @@
 
 #include "sdf/Element.hh"
 #include "sdf/Filesystem.hh"
+#include "sdf/ForceTorque.hh"
 #include "sdf/Joint.hh"
 #include "sdf/JointAxis.hh"
 #include "sdf/Link.hh"
 #include "sdf/Model.hh"
 #include "sdf/Root.hh"
 #include "sdf/SDFImpl.hh"
+#include "sdf/Sensor.hh"
 #include "sdf/Types.hh"
 #include "sdf/parser.hh"
 #include "test_config.h"
@@ -63,8 +65,7 @@ TEST(DOMJoint, NoName)
 TEST(DOMJoint, DoublePendulum)
 {
   const std::string testFile =
-    sdf::filesystem::append(PROJECT_SOURCE_PATH, "test", "sdf",
-        "double_pendulum.sdf");
+    sdf::testing::TestFile("sdf", "double_pendulum.sdf");
 
   // Load the SDF file
   sdf::Root root;
@@ -117,8 +118,7 @@ TEST(DOMJoint, DoublePendulum)
 TEST(DOMJoint, Complete)
 {
   const std::string testFile =
-    sdf::filesystem::append(PROJECT_SOURCE_PATH, "test", "sdf",
-        "joint_complete.sdf");
+    sdf::testing::TestFile("sdf", "joint_complete.sdf");
 
   // Load the SDF file
   sdf::Root root;
@@ -160,8 +160,7 @@ TEST(DOMJoint, Complete)
 TEST(DOMJoint, LoadJointParentWorld)
 {
   const std::string testFile =
-    sdf::filesystem::append(PROJECT_SOURCE_PATH, "test", "sdf",
-        "joint_parent_world.sdf");
+    sdf::testing::TestFile("sdf", "joint_parent_world.sdf");
 
   // Load the SDF file
   sdf::Root root;
@@ -204,8 +203,7 @@ TEST(DOMJoint, LoadJointParentWorld)
 TEST(DOMJoint, LoadInvalidJointChildWorld)
 {
   const std::string testFile =
-    sdf::filesystem::append(PROJECT_SOURCE_PATH, "test", "sdf",
-        "joint_child_world.sdf");
+    sdf::testing::TestFile("sdf", "joint_child_world.sdf");
 
   // Load the SDF file
   sdf::Root root;
@@ -229,8 +227,7 @@ TEST(DOMJoint, LoadInvalidJointChildWorld)
 TEST(DOMJoint, LoadJointPoseRelativeTo)
 {
   const std::string testFile =
-    sdf::filesystem::append(PROJECT_SOURCE_PATH, "test", "sdf",
-        "model_joint_relative_to.sdf");
+    sdf::testing::TestFile("sdf", "model_joint_relative_to.sdf");
 
   // Load the SDF file
   sdf::Root root;
@@ -324,7 +321,7 @@ TEST(DOMJoint, LoadJointPoseRelativeTo)
 TEST(DOMJoint, LoadInvalidJointPoseRelativeTo)
 {
   const std::string testFile =
-    sdf::filesystem::append(PROJECT_SOURCE_PATH, "test", "sdf",
+    sdf::testing::TestFile("sdf",
         "model_invalid_joint_relative_to.sdf");
 
   // Load the SDF file
@@ -353,8 +350,7 @@ TEST(DOMJoint, LoadInvalidJointPoseRelativeTo)
 TEST(DOMJoint, LoadInvalidChild)
 {
   const std::string testFile =
-    sdf::filesystem::append(PROJECT_SOURCE_PATH, "test", "sdf",
-        "joint_invalid_child.sdf");
+    sdf::testing::TestFile("sdf", "joint_invalid_child.sdf");
 
   // Load the SDF file
   sdf::Root root;
@@ -383,7 +379,7 @@ TEST(DOMJoint, LoadInvalidChild)
 TEST(DOMJoint, LoadLinkJointSameName17Invalid)
 {
   const std::string testFile =
-    sdf::filesystem::append(PROJECT_SOURCE_PATH, "test", "sdf",
+    sdf::testing::TestFile("sdf",
         "model_link_joint_same_name.sdf");
 
   // Read with sdf::readFile, which converts from 1.6 to latest
@@ -414,8 +410,7 @@ TEST(DOMJoint, LoadLinkJointSameName17Invalid)
 TEST(DOMJoint, LoadLinkJointSameName16Valid)
 {
   const std::string testFile =
-    sdf::filesystem::append(PROJECT_SOURCE_PATH, "test", "sdf",
-        "model_link_joint_same_name.sdf");
+    sdf::testing::TestFile("sdf", "model_link_joint_same_name.sdf");
 
   // Load the SDF file
   sdf::Root root;
@@ -493,8 +488,7 @@ TEST(DOMJoint, LoadLinkJointSameName16Valid)
 TEST(DOMJoint, LoadURDFJointPoseRelativeTo)
 {
   const std::string testFile =
-    sdf::filesystem::append(PROJECT_SOURCE_PATH, "test", "integration",
-        "provide_feedback.urdf");
+    sdf::testing::TestFile("integration", "provide_feedback.urdf");
 
   // Load the SDF file
   sdf::Root root;
@@ -572,3 +566,61 @@ TEST(DOMJoint, LoadURDFJointPoseRelativeTo)
     model->JointByName("joint12")->Axis()->ResolveXyz(vec3, "joint12").empty());
   EXPECT_EQ(Vector3(0, 1.0, 0), vec3);
 }
+
+//////////////////////////////////////////////////
+TEST(DOMJoint, Sensors)
+{
+  const std::string testFile =
+      sdf::testing::TestFile("sdf", "joint_sensors.sdf");
+
+  // Load the SDF file
+  sdf::Root root;
+  auto errors = root.Load(testFile);
+  EXPECT_TRUE(errors.empty());
+  for (const auto &err : errors)
+  {
+    std::cout << err << std::endl;
+  }
+
+  // Get the first model
+  const sdf::Model *model = root.ModelByIndex(0);
+  ASSERT_NE(nullptr, model);
+  EXPECT_EQ("model", model->Name());
+
+  // Get the first joint
+  const sdf::Joint *joint = model->JointByIndex(0);
+  ASSERT_NE(nullptr, joint);
+  EXPECT_EQ("joint", joint->Name());
+  EXPECT_EQ(1u, joint->SensorCount());
+
+  ignition::math::Pose3d pose;
+
+  // Get the force_torque sensor
+  const sdf::Sensor *forceTorqueSensor =
+    joint->SensorByName("force_torque_sensor");
+  ASSERT_NE(nullptr, forceTorqueSensor);
+  EXPECT_EQ("force_torque_sensor", forceTorqueSensor->Name());
+  EXPECT_EQ(sdf::SensorType::FORCE_TORQUE, forceTorqueSensor->Type());
+  EXPECT_EQ(ignition::math::Pose3d(10, 11, 12, 0, 0, 0),
+      forceTorqueSensor->RawPose());
+  auto forceTorqueSensorObj = forceTorqueSensor->ForceTorqueSensor();
+  ASSERT_NE(nullptr, forceTorqueSensorObj);
+  EXPECT_EQ(sdf::ForceTorqueFrame::PARENT, forceTorqueSensorObj->Frame());
+  EXPECT_EQ(sdf::ForceTorqueMeasureDirection::PARENT_TO_CHILD,
+      forceTorqueSensorObj->MeasureDirection());
+
+  EXPECT_DOUBLE_EQ(0.0, forceTorqueSensorObj->ForceXNoise().Mean());
+  EXPECT_DOUBLE_EQ(0.1, forceTorqueSensorObj->ForceXNoise().StdDev());
+  EXPECT_DOUBLE_EQ(1.0, forceTorqueSensorObj->ForceYNoise().Mean());
+  EXPECT_DOUBLE_EQ(1.1, forceTorqueSensorObj->ForceYNoise().StdDev());
+  EXPECT_DOUBLE_EQ(2.0, forceTorqueSensorObj->ForceZNoise().Mean());
+  EXPECT_DOUBLE_EQ(2.1, forceTorqueSensorObj->ForceZNoise().StdDev());
+
+  EXPECT_DOUBLE_EQ(3.0, forceTorqueSensorObj->TorqueXNoise().Mean());
+  EXPECT_DOUBLE_EQ(3.1, forceTorqueSensorObj->TorqueXNoise().StdDev());
+  EXPECT_DOUBLE_EQ(4.0, forceTorqueSensorObj->TorqueYNoise().Mean());
+  EXPECT_DOUBLE_EQ(4.1, forceTorqueSensorObj->TorqueYNoise().StdDev());
+  EXPECT_DOUBLE_EQ(5.0, forceTorqueSensorObj->TorqueZNoise().Mean());
+  EXPECT_DOUBLE_EQ(5.1, forceTorqueSensorObj->TorqueZNoise().StdDev());
+
+}
